@@ -10,6 +10,7 @@ from clndr.models.calendars import Calendars
 from clndr.models.holidays import Holidays
 from clndr.models.shift_day_relax import Shift_day_relax
 from isc_common.auth.models.user import User
+from isc_common.common import uuid4
 from isc_common.ws.progressStack import ProgressStack
 
 
@@ -114,7 +115,7 @@ class Timeline:
             if month_range < startDate.day + 1:
                 if red_label_day.month + 1 > 12:
                     self.shiftsList.add(CalendarEvent(
-                        id=str(uuid.uuid4()),
+                        id=uuid4(),
                         backgroundColor=red_label_day.daytype.color,
                         endDate=datetime.datetime(year=startDate.year + 1, month=1, day=1),
                         isredlabelday=True,
@@ -124,7 +125,7 @@ class Timeline:
                     ))
                 else:
                     self.shiftsList.add(CalendarEvent(
-                        id=str(uuid.uuid4()),
+                        id=uuid4(),
                         backgroundColor=red_label_day.daytype.color,
                         endDate=datetime.datetime(year=startDate.year, month=startDate.month + 1, day=1),
                         isredlabelday=True,
@@ -134,7 +135,7 @@ class Timeline:
                     ))
             else:
                 self.shiftsList.add(CalendarEvent(
-                    id=str(uuid.uuid4()),
+                    id=uuid4(),
                     backgroundColor=red_label_day.daytype.color,
                     endDate=datetime.datetime(year=startDate.year, month=startDate.month, day=startDate.day + 1),
                     isredlabelday=True,
@@ -172,7 +173,7 @@ class Timeline:
         # print(f'endDate: {endDate}')
 
         self.shiftsList.add(CalendarEvent(
-            id=str(uuid.uuid4()),
+            id=uuid4(),
             backgroundColor=shiftday.daytype.color,
             description=f'{shift.shift.name} {shiftday.description if shiftday.description else ""}',
             endDate=endDate,
@@ -201,7 +202,7 @@ class Timeline:
 
                 # Данные перекура
                 self.relaxesList.add(CalendarEvent(
-                    id=str(uuid.uuid4()),
+                    id=uuid4(),
                     backgroundColor=shift_day_relax.color,
                     description=f'{shift.shift.name} ({shift_day_relax.name})',
                     endDate=endDateRelax,
@@ -219,7 +220,7 @@ class Timeline:
     def build(self, data):
         self.curdate = self.calendar.begindate
         enddate = self.calendar.enddate
-        if data.get('user_id') is None or not isinstance(data.get('user_id'), int):
+        if data.get('user_id') == None or not isinstance(data.get('user_id'), int):
             raise Exception(f'user_id not found')
         user = User.objects.get(id=data.get('user_id'))
 
