@@ -7,7 +7,7 @@ from isc_common.fields import Field
 class FieldFileEx(FieldFile, Field):
     def open(self, mode='rb'):
         self._require_file()
-        if getattr(self, '_file', None) is None:
+        if getattr(self, '_file', None) == None:
             if isinstance(settings.REPLACE_FILE_PATH, dict):
                 for key, value in settings.REPLACE_FILE_PATH.items():
                     self.name = self.name.replace(key, value)
