@@ -2,14 +2,14 @@ from datetime import datetime
 
 
 def str2Date(date_str):
-    if date_str is None:
+    if date_str == None:
         return None
     else:
         return datetime.strptime(date_str, '%Y-%m-%dT%I:%M:%S.%fZ').date()
 
 
 def str2Date4Django(date_str):
-    if date_str is None:
+    if date_str == None:
         return None
     else:
         date = str2Date(date_str)
