@@ -8,6 +8,19 @@ from django.db.models import ForeignKey
 from isc_common import setAttr
 
 
+def del_last_zero(value):
+    if isinstance(value, str):
+        return value
+
+    res = str(value)
+    res.split('.')
+    cel = res.split('.')[0]
+    float = StrToNumber(res.split('.')[1:][0])
+    if float > 0:
+        return f'{cel}.{float}'
+    return cel
+
+
 def DecimalToStr(value):
     if value == None:
         return ''
@@ -16,13 +29,7 @@ def DecimalToStr(value):
         # if value == 0:
         #     return None
 
-        res = str(value)
-        res.split('.')
-        cel = res.split('.')[0]
-        float = StrToNumber(res.split('.')[1:][0])
-        if float > 0:
-            return f'{cel}.{float}'
-        return cel
+        return del_last_zero(value=value)
     except IndexError:
         return value
 
@@ -57,12 +64,31 @@ def IntToNumber(s):
     return float(s)
 
 
+def IntToStr(value):
+    if value == None:
+        return None
+
+    if not isinstance(value, str):
+        return value
+
+    if not isinstance(value, int):
+        return del_last_zero(value=value)
+
+    raise Exception(f'{value}  must be int')
+
+
 def ToStr(s):
     if s == None or s == 'null':
         return None
 
     if not isinstance(s, str):
-        return str(s)
+        return s
+
+    if not isinstance(s, Decimal):
+        return DecimalToStr(s)
+
+    if not isinstance(s, int):
+        return del_last_zero(value=s)
 
     return s
 
@@ -83,6 +109,22 @@ def ToNumber(s):
         raise Exception(f'{s} unknown type.')
 
 
+def ToInt(s):
+    if s == None:
+        return None
+
+    if isinstance(s, int):
+        return s
+    elif isinstance(s, str):
+        return StrToNumber(s)
+    elif isinstance(s, float):
+        return int(s)
+    elif isinstance(s, Decimal):
+        return int(s)
+    else:
+        raise Exception(f'{s} unknown type.')
+
+
 def ToDecimal(s):
     if s == None:
         return 0
